@@ -5,8 +5,15 @@
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Nic Dahlquist <nic@snapchat.com>                              #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
-# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
+# This file is part of PyGithub.                                               #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -23,29 +30,40 @@
 #                                                                              #
 ################################################################################
 
+import github.GithubObject
+
 
 class InputGitAuthor(object):
     """
+    This class represents InputGitAuthors
     """
 
-    def __init__(self, name, email, date):
+    def __init__(self, name, email, date=github.GithubObject.NotSet):
         """
         :param name: string
         :param email: string
         :param date: string
         """
 
-        assert isinstance(name, (str, unicode)), name
-        assert isinstance(email, (str, unicode)), email
-        assert isinstance(date, (str, unicode)), date  # @todo Datetime?
+        assert isinstance(name, str), name
+        assert isinstance(email, str), email
+        assert date is github.GithubObject.NotSet or isinstance(
+            date, str
+        ), date  # @todo Datetime?
+
         self.__name = name
         self.__email = email
         self.__date = date
 
+    def __repr__(self):
+        return 'InputGitAuthor(name="{}")'.format(self.__name)
+
     @property
     def _identity(self):
-        return {
+        identity = {
             "name": self.__name,
             "email": self.__email,
-            "date": self.__date,
         }
+        if self.__date is not github.GithubObject.NotSet:
+            identity["date"] = self.__date
+        return identity
